Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(473)

Unified Diff: components/certificate_reporting/error_reporter.h

Issue 2026213002: Refactor CertificateReportSender (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 4 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: components/certificate_reporting/error_reporter.h
diff --git a/components/certificate_reporting/error_reporter.h b/components/certificate_reporting/error_reporter.h
index f94172e0941ce8524707088e8c524f32d98d24e4..ed4a1ee98acfbb81498ddd49b35b798b6242e0df 100644
--- a/components/certificate_reporting/error_reporter.h
+++ b/components/certificate_reporting/error_reporter.h
@@ -12,7 +12,7 @@
#include <string>
#include "base/macros.h"
-#include "net/url_request/certificate_report_sender.h"
+#include "net/url_request/report_sender.h"
#include "url/gurl.h"
namespace net {
@@ -32,19 +32,17 @@ class ErrorReporter {
// error reports to |upload_url|, using |request_context| as the
// context for the reports. |cookies_preference| controls whether
// cookies will be sent along with the reports.
- ErrorReporter(
- net::URLRequestContext* request_context,
- const GURL& upload_url,
- net::CertificateReportSender::CookiesPreference cookies_preference);
+ ErrorReporter(net::URLRequestContext* request_context,
+ const GURL& upload_url,
+ net::ReportSender::CookiesPreference cookies_preference);
// Allows tests to use a server public key with known private key and
// a mock CertificateReportSender. |server_public_key| must outlive
// the ErrorReporter.
- ErrorReporter(
- const GURL& upload_url,
- const uint8_t server_public_key[/* 32 */],
- const uint32_t server_public_key_version,
- std::unique_ptr<net::CertificateReportSender> certificate_report_sender);
+ ErrorReporter(const GURL& upload_url,
+ const uint8_t server_public_key[/* 32 */],
+ const uint32_t server_public_key_version,
+ std::unique_ptr<net::ReportSender> certificate_report_sender);
virtual ~ErrorReporter();
@@ -75,7 +73,7 @@ class ErrorReporter {
std::string* decrypted_serialized_report);
private:
- std::unique_ptr<net::CertificateReportSender> certificate_report_sender_;
+ std::unique_ptr<net::ReportSender> certificate_report_sender_;
const GURL upload_url_;
« no previous file with comments | « chrome/browser/ssl/chrome_expect_ct_reporter_unittest.cc ('k') | components/certificate_reporting/error_reporter.cc » ('j') | no next file with comments »
@@ -32,19 +32,17 @@ class ErrorReporter {
// Allows tests to use a server public key with known private key and
- // a mock CertificateReportSender. |server_public_key| must outlive
+ // a mock ReportSender. |server_public_key| must outlive
// the ErrorReporter.

Powered by Google App Engine
This is Rietveld 408576698